library(ggplot2)
library(ggsignif)
library(reshape2)

task <- read.csv("data_task.csv")
consent <- read.csv("data_consent.csv")
debrief <- read.csv("data_debrief.csv")

# remove unwanted rows in task 

followup_task <- subset(task, task$Screen.Number=="3" & task$Zone.Type=="response_rating_scale_likert")

# add numeric response for likert scale 

#if (subset(followup_task, followup_task$Response=="Good") followup_task$Response_no <- "4"
followup_task$Response_no <-  with(followup_task, ifelse(Response=="Good", 4, 
                                                         ifelse(Response=="Kind of good", 3, 
                                                                ifelse(Response=="Kind of bad", 2, 1))))

# order responses

followup_task$Response <- factor(followup_task$Response) 

followup_task$Response <- factor(followup_task$Response, levels = c("Bad", "Kind of bad", "Kind of good", "Good"))

# plot responses by condition 

# histogram labels 

followup_labels <- c("Ambiguous", "Critical", "Fully informative", "Implicature")
names(followup_labels) <- c("ambiguous", "critical", "fullyinformative", "implicature")


followup_histogram <- ggplot (followup_task, aes(Response_no))
followup_histogram + geom_histogram(stat="count") + facet_wrap(~metadata_condition, labeller = labeller(metadata_condition=followup_labels, Response_no=followup_labels_response)) + 
  theme( panel.background = element_rect(fill="white"), panel.grid.major = element_line(colour = "grey", size = .2)) + 
  xlab("Response") + ggsave("Followup_histogram.png", width = 6, height = 6)


         
# calculate proportion of responses per condition 


aggregate(metadata_condition~Response, 
          data = subset(followup_task, followup_task$metadata_condition=="implicature"), FUN = length)


aggregate(metadata_condition~Response, 
          data = subset(followup_task, followup_task$metadata_condition=="ambiguous"), FUN = length)


aggregate(metadata_condition~Response, 
          data = subset(followup_task, followup_task$metadata_condition=="fullyinformative"), FUN = length)


aggregate(metadata_condition~Response, 
          data = subset(followup_task, followup_task$metadata_condition=="critical"), FUN = length)


#plot responses by condition percentages

followup_percent <- read.csv("followup_percentages.csv")
colnames(followup_percent)[1] <- "Rating"
colnames(followup_percent)[5] <- "Fully informative"
followup_percent <- melt(followup_percent, measure.vars = c("Ambiguous", "Critical", "Implicature", "Fully informative"))
followup_percent$percent <- followup_percent$value/100

followup_results <- ggplot(followup_percent, aes(Rating,percent))
followup_results + stat_identity(geom = "bar") + facet_wrap(~variable)+
  scale_x_discrete(limits = c("Bad", "Kind of bad", "Kind of good", "Good"))+
  ylab("Proportion of rating selected") +
  theme(panel.background = element_rect(fill = "white"), panel.grid.major = element_line(colour = "grey"), axis.text.x = element_text(angle = -45, hjust = 0, size = 12))+
  ggsave("Followup_results.png")
